Embedded Videos
---------------

Our toolset provides a number of different things that will help you to learn to program in the Python programming language.
Aside from reading the text, it is sometimes useful to hear someone tell you about different aspects of the topic being discussed.
In order to accomplish this, we provide a way to integrate simple, short videos into the text.  For example, if you click
on the video shown below, you will hear us talk about the tools that will be described shortly.

.. video:: over_videoinfo
    :controls:
    :thumb: _static/activecodethumb.png

    http://media.interactivepython.org/runestone.mov
    http://media.interactivepython.org/runestone.webm


.. reveal:: videoinfo_src
   :showtitle: Show Source
   :hidetitle: Hide Source
   :modaltitle: Source for the example above

   .. code-block:: rst

      .. video:: videoinfo
          :controls:
          :thumb: _static/activecodethumb.png

          http://media.interactivepython.org/runestone.mov
          http://media.interactivepython.org/runestone.webm

